﻿using C1.WPF;
using C1.WPF.DateTimeEditors;
using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Markup;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DateTimeContextMenu
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        // DatePicker
        private void datePicker_PreviewKeyDown(object sender, KeyEventArgs e)
        {
            if (Keyboard.Modifiers == ModifierKeys.Alt && e.SystemKey == Key.F)
            {
                datePicker.FinalizeEditing();
            }
        }

        // TimeEditor
        private void timeEditor_PreviewKeyDown(object sender, KeyEventArgs e)
        {
            if (Keyboard.Modifiers == ModifierKeys.Alt && e.SystemKey == Key.F)
            {
                timeEditor.FinalizeEditing();                  
            }
        }

        private void datePicker_PreviewMouseRightButtonUp(object sender, MouseButtonEventArgs e)
        {
            datePicker.ContextMenu.IsOpen = true;
            datePicker.ContextMenu.PlacementTarget = datePicker;
        }

        private void btnOpenPopup_Click(object sender, RoutedEventArgs e)
        {
            PopupWindow popupWindow = new PopupWindow();
            popupWindow.Show();
        }
    }

    public static class Extensions
    {
        public static void FinalizeEditing(this C1TimeEditor timeEditor)
        {
            var maskedTextBox = timeEditor.Template.FindName("TextBox", timeEditor) as C1MaskedTextBox;
            string[] formats = new string[] { "hh:mm:ss tt", "h:m:s tt", "hh:mm:ss", "h:m:s" };
            if (!DateTime.TryParseExact(maskedTextBox.Text, formats, CultureInfo.InvariantCulture, DateTimeStyles.AssumeLocal, out DateTime time))
            {
                TimeSpan timeSpan = timeEditor.Value.Value;
                maskedTextBox.Text = new DateTime().Add(timeSpan).ToLongTimeString();
            }
            else
            {
                timeEditor.Value = time.TimeOfDay;
            }
        }
    }
}
